@@ -1,7 +1,6 @@
 alpha.fun <-
 function(n.pergrp, del.cut, k, T, p.c, effect.size, 
-               #rep=500, pathcode=paste(installed.packages()['hbdct',2], "/hbdct",sep=""), codefile="BUGS_Bin_2arm.txt", pathout=getwd(), hyper) {
-			   rep=500, pathcode=getwd(), codefile="BUGS_Bin_2arm.txt", pathout=getwd(), hyper) {
+               rep=500, pathcode=path.package("hbdct"), codefile="BUGS_Bin_2arm.txt", pathout=getwd()) {
   n.c <- rep(n.pergrp, k)
   n.t <- n.c
 
@@ -18,14 +17,9 @@ function(n.pergrp, del.cut, k, T, p.c, effect.size,
   cat(colname, '\n', file=filename, sep=' ', append=TRUE)
 
   for (i in 1:rep) {
-    bug.res <- brugs.bin.2arm(p.c=p.c, p.t=p.t0, n.c=n.c, n.t=n.t, 
-                              pathcode=pathcode, codefile=codefile, del.cut=del.cut, hyper=hyper)
-
-    if (!is.na(bug.res)){
-      cat(i, bug.res, '\n', file=filename, sep=' ', append=TRUE)
-    }else{
-      next;
-    }
+    bug.res <- brugs.bin.2arm(p.c=p.c, p.t=p.t0, n.c=n.c, n.t=n.t,
+                         pathcode=pathcode, codefile=codefile, del.cut=del.cut)
+    cat(i, bug.res, '\n', file=filename, sep=' ', append=TRUE)
   }
 
   post.null <- read.table(filename, header=TRUE, skip=2)
